@@ -121,30 +121,61 @@ class RosRules(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "endpointId", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="refreshOptions")
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], jsii.get(self, "refreshOptions"))
+
+    @refresh_options.setter
+    def refresh_options(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7ac092c5f42b740f1fed8dbf0b486f7cbda27bfc75955ba11f948453ef33f4d8)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "refreshOptions", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.datasource.RosRulesProps",
     jsii_struct_bases=[],
-    name_mapping={"endpoint_id": "endpointId"},
+    name_mapping={"endpoint_id": "endpointId", "refresh_options": "refreshOptions"},
 )
 class RosRulesProps:
     def __init__(
         self,
         *,
         endpoint_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``RosRules``.
 
         See https://www.alibabacloud.com/help/ros/developer-reference/datasource-pvtz-rules
 
         :param endpoint_id: 
+        :param refresh_options: 
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__f2cf582c5a025c58d8fbde718ae5a43b28bf167925e2331f05a70b20c4d55ae0)
             check_type(argname="argument endpoint_id", value=endpoint_id, expected_type=type_hints["endpoint_id"])
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if endpoint_id is not None:
             self._values["endpoint_id"] = endpoint_id
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
 
     @builtins.property
     def endpoint_id(
@@ -156,6 +187,22 @@ class RosRulesProps:
         result = self._values.get("endpoint_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -254,6 +301,32 @@ class RosZones(
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="refreshOptions")
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], jsii.get(self, "refreshOptions"))
+
+    @refresh_options.setter
+    def refresh_options(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+    ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__32af3b24ef27808675810d5730e25b95c192f5d17963861f1b03b2859d938107)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "refreshOptions", value)
+
     @builtins.property
     @jsii.member(jsii_name="resourceGroupId")
     def resource_group_id(
@@ -278,27 +351,51 @@ class RosZones(
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.datasource.RosZonesProps",
     jsii_struct_bases=[],
-    name_mapping={"resource_group_id": "resourceGroupId"},
+    name_mapping={
+        "refresh_options": "refreshOptions",
+        "resource_group_id": "resourceGroupId",
+    },
 )
 class RosZonesProps:
     def __init__(
         self,
         *,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``RosZones``.
 
         See https://www.alibabacloud.com/help/ros/developer-reference/datasource-pvtz-zones
 
+        :param refresh_options: 
         :param resource_group_id: 
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__cdc77d31e64e80f26b1f30064266e84feaa18b4ea09ed634acbccca4c6b24644)
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
             check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
         if resource_group_id is not None:
             self._values["resource_group_id"] = resource_group_id
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''
+        :Property:
+
+        refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+        Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     @builtins.property
     def resource_group_id(
         self,
@@ -420,26 +517,31 @@ class Rules(
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.datasource.RulesProps",
     jsii_struct_bases=[],
-    name_mapping={"endpoint_id": "endpointId"},
+    name_mapping={"endpoint_id": "endpointId", "refresh_options": "refreshOptions"},
 )
 class RulesProps:
     def __init__(
         self,
         *,
         endpoint_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``Rules``.
 
         See https://www.alibabacloud.com/help/ros/developer-reference/datasource-pvtz-rules
 
         :param endpoint_id: Property endpointId: EndpointId.
+        :param refresh_options: Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values: - Never: Never refresh the datasource resource when the stack is updated. - Always: Always refresh the datasource resource when the stack is updated. Default is Never.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__4681dcc30d21eb15fdc6ccd884ed9cca9b015eee5a3abdd5f61ae4f97f946ad5)
             check_type(argname="argument endpoint_id", value=endpoint_id, expected_type=type_hints["endpoint_id"])
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if endpoint_id is not None:
             self._values["endpoint_id"] = endpoint_id
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
 
     @builtins.property
     def endpoint_id(
@@ -449,6 +551,21 @@ class RulesProps:
         result = self._values.get("endpoint_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated.
+
+        Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+          Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -560,27 +677,50 @@ class Zones(
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.datasource.ZonesProps",
     jsii_struct_bases=[],
-    name_mapping={"resource_group_id": "resourceGroupId"},
+    name_mapping={
+        "refresh_options": "refreshOptions",
+        "resource_group_id": "resourceGroupId",
+    },
 )
 class ZonesProps:
     def __init__(
         self,
         *,
+        refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         resource_group_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``Zones``.
 
         See https://www.alibabacloud.com/help/ros/developer-reference/datasource-pvtz-zones
 
+        :param refresh_options: Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated. Valid values: - Never: Never refresh the datasource resource when the stack is updated. - Always: Always refresh the datasource resource when the stack is updated. Default is Never.
         :param resource_group_id: Property resourceGroupId: ResourceGroupId.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__a71ef3a88d24fb5ca41d6cd3ae5d6128829dc84b231e1fe328474675fa153042)
+            check_type(argname="argument refresh_options", value=refresh_options, expected_type=type_hints["refresh_options"])
             check_type(argname="argument resource_group_id", value=resource_group_id, expected_type=type_hints["resource_group_id"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
+        if refresh_options is not None:
+            self._values["refresh_options"] = refresh_options
         if resource_group_id is not None:
             self._values["resource_group_id"] = resource_group_id
 
+    @builtins.property
+    def refresh_options(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]]:
+        '''Property refreshOptions: The refresh strategy for the datasource resource when the stack is updated.
+
+        Valid values:
+
+        - Never: Never refresh the datasource resource when the stack is updated.
+        - Always: Always refresh the datasource resource when the stack is updated.
+          Default is Never.
+        '''
+        result = self._values.get("refresh_options")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]], result)
+
     @builtins.property
     def resource_group_id(
         self,
@@ -641,9 +781,16 @@ def _typecheckingstub__f65e4ae79da24d0ad0a66f480b6ccc33576c419bb7ff016d718482048
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__7ac092c5f42b740f1fed8dbf0b486f7cbda27bfc75955ba11f948453ef33f4d8(
+    value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__f2cf582c5a025c58d8fbde718ae5a43b28bf167925e2331f05a70b20c4d55ae0(
     *,
     endpoint_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -669,6 +816,12 @@ def _typecheckingstub__ad9bb8a3eb9d1fa8ff6437acc09600d1583f4cb369c25794a08e64ef0
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__32af3b24ef27808675810d5730e25b95c192f5d17963861f1b03b2859d938107(
+    value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__fede0e4732f016a5ea27fcc1d264604fd4ccbe339fdad020e53ceadd207e0263(
     value: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]],
 ) -> None:
@@ -677,6 +830,7 @@ def _typecheckingstub__fede0e4732f016a5ea27fcc1d264604fd4ccbe339fdad020e53ceadd2
 
 def _typecheckingstub__cdc77d31e64e80f26b1f30064266e84feaa18b4ea09ed634acbccca4c6b24644(
     *,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     resource_group_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -718,6 +872,7 @@ def _typecheckingstub__15f9bc3691b6d22bab8d7ba3062049bbea6e340057cfdcf435c8ff4c0
 def _typecheckingstub__4681dcc30d21eb15fdc6ccd884ed9cca9b015eee5a3abdd5f61ae4f97f946ad5(
     *,
     endpoint_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -757,6 +912,7 @@ def _typecheckingstub__4f01fcfafb5513b5eddfcbe2c5f1ecfd1550d199bf8bfdaf731ff7271
 
 def _typecheckingstub__a71ef3a88d24fb5ca41d6cd3ae5d6128829dc84b231e1fe328474675fa153042(
     *,
+    refresh_options: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     resource_group_id: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
 ) -> None:
     """Type checking stubs"""
